@@ -180,7 +180,7 @@ typedef struct {
   } chan[2];
 } priv_t;
 
-static int getopts(sox_effect_t * effp, int argc, char **argv)
+static int getopts_reverb(sox_effect_t * effp, int argc, char **argv)
 {
   priv_t * p = (priv_t *)effp->priv;
   p->reverberance = p->hf_damping = 50; /* Set non-zero defaults */
@@ -201,7 +201,7 @@ static int getopts(sox_effect_t * effp, int argc, char **argv)
   return argc ? lsx_usage(effp) : SOX_SUCCESS;
 }
 
-static int start(sox_effect_t * effp)
+static int start_reverb(sox_effect_t * effp)
 {
   priv_t * p = (priv_t *)effp->priv;
   size_t i;
@@ -228,7 +228,7 @@ static int start(sox_effect_t * effp)
   return SOX_SUCCESS;
 }
 
-static int flow(sox_effect_t * effp, const sox_sample_t * ibuf,
+static int flow_reverb(sox_effect_t * effp, const sox_sample_t * ibuf,
                 sox_sample_t * obuf, size_t * isamp, size_t * osamp)
 {
   priv_t * p = (priv_t *)effp->priv;
@@ -254,7 +254,7 @@ static int flow(sox_effect_t * effp, const sox_sample_t * ibuf,
   return SOX_SUCCESS;
 }
 
-static int stop(sox_effect_t * effp)
+static int stop_reverb(sox_effect_t * effp)
 {
   priv_t * p = (priv_t *)effp->priv;
   size_t i;
@@ -265,6 +265,10 @@ static int stop(sox_effect_t * effp)
 
 sox_effect_handler_t const *lsx_reverb_effect_fn(void)
 {
+  static char const * const extra_usage[] = {
+    "-w  Output only the `wet' signal",
+    NULL
+  };
   static sox_effect_handler_t handler = {"reverb",
     "[-w]"
     " [reverberance(50%)"
@@ -273,9 +277,11 @@ sox_effect_handler_t const *lsx_reverb_effect_fn(void)
     " [stereo-depth(100%)"
     " [pre-delay(0ms)"
     " [wet-gain(0dB)"
-    "]]]]]]", NULL,
+    "]]]]]]",
     SOX_EFF_MCHAN | SOX_EFF_CHAN,
-    getopts, start, flow, NULL, stop, NULL, sizeof(priv_t)
+    getopts_reverb, start_reverb, flow_reverb, NULL, stop_reverb, NULL,
+    sizeof(priv_t),
+    extra_usage,
   };
   return &handler;
 }
